@@ -12,7 +12,7 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: addressbook.cc,v 1.78 2004/04/11 17:37:59 binner Exp $	 
+   $Id: addressbook.cc 628321 2007-01-29 18:53:56Z kossebau $	 
 */
 
 #include "addressbook.h"
@@ -116,7 +116,7 @@ class StringKabKeyMap : public map<QString, KabKey, QStringLess>
 };
 
 // ----- another derived map class:
-class KeyNameMap : public map<const char*, const QString, less<const char*> >
+class KeyNameMap : public map<const char*, QString, less<const char*> >
 { // same thing
 };
 
@@ -164,47 +164,47 @@ bool AddressBook::Entry::Address::nameOfField(const char* key, QString& value)
       fields=new KeyNameMap;
       Q_CHECK_PTR(fields);
       if(!fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Headline"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Position"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Organization"))).second 
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Department"))).second 
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Sub-Department"))).second 
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Delivery Label"))).second 
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
-	 (Fields[counter++], i18n("Address"))).second
+	 (map<const char*, QString, less<const char*> >::value_type
+	 (Fields[counter++], i18n("street/postal","Address"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Zipcode"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("City"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Country"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("As in addresses", "State"))).second)
 	{
 	  kdDebug(KAB_KDEBUG_AREA) 
@@ -259,83 +259,83 @@ bool AddressBook::Entry::nameOfField(const char* key, QString& value)
       fields=new KeyNameMap;
       Q_CHECK_PTR(fields);
       if(!fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
-	  (Fields[counter++], i18n("Title"))).second
+	 (map<const char*, QString, less<const char*> >::value_type
+	  (Fields[counter++], i18n("person","Title"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Rank"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Formatted Name"))).second 
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Name Prefix"))).second 
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("First Name"))).second 
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Middle Name"))).second 
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	 (Fields[counter++], i18n("Last Name"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Birthday"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Comment"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Talk Addresses"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Email Addresses"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Keywords"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Telephone Number"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("URLs"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("User Field 1"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("User Field 2"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("User Field 3"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("User Field 4"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Custom"))).second
 	 ||
 	 !fields->insert
-	 (map<const char*, const QString, less<const char*> >::value_type
+	 (map<const char*, QString, less<const char*> >::value_type
 	  (Fields[counter++], i18n("Categories"))).second)
 	{
 	  kdDebug(KAB_KDEBUG_AREA) 
@@ -579,7 +579,7 @@ AddressBook::ErrorCode AddressBook::load(const QString& filename)
 	      i18n("File Error"),
 	      KStdGuiItem::close(), KStdGuiItem::save()))
 	    {
-	    case 1: // save
+	    case KMessageBox::No: // save
 	      if(!data->save(i18n("(Safety copy on file error)").ascii(), true))
 		{
 		  KMessageBox::information(this,
@@ -622,7 +622,7 @@ AddressBook::ErrorCode AddressBook::load(const QString& filename)
 	      i18n("The file \"%1\" cannot be found. "
 	           "Create a new one?").arg(fname), 
 	      i18n("No Such File"),
-	      KStdGuiItem::ok(), KStdGuiItem::cancel())==0)
+	      i18n("Create"), KStdGuiItem::cancel())==KMessageBox::Yes)
 	    {
 	      if(createNew(fname)==NoError)
 		{
