@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kicontheme.cpp,v 1.63.2.5 2004/10/03 14:28:58 waba Exp $
+ * $Id: kicontheme.cpp 601485 2006-11-03 12:50:30Z lunakl $
  *
  * This file is part of the KDE project, module kdecore.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -106,6 +106,10 @@ KIconTheme::KIconTheme(const QString& name, const QString& appName)
     // Find the theme description file. These are always global.
 
     icnlibs = KGlobal::dirs()->resourceDirs("icon");
+    icnlibs += KGlobal::dirs()->resourceDirs("xdgdata-icon");
+    icnlibs += "/usr/share/pixmaps";
+    // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
+    icnlibs += KGlobal::dirs()->resourceDirs("xdgdata-pixmap");
     for (it=icnlibs.begin(); it!=icnlibs.end(); ++it)
     {
         cDir = *it + name + "/";
@@ -340,6 +344,20 @@ QStringList KIconTheme::queryIconsByContext(int size, KIcon::Context context) co
     return iconlistResult;
 }
 
+bool KIconTheme::hasContext(KIcon::Context context) const
+{
+    QPtrListIterator<KIconThemeDir> dirs(mDirs);
+    KIconThemeDir *dir;
+
+    for ( ; dirs.current(); ++dirs)
+    {
+        dir = dirs.current();
+        if ((context == KIcon::Any) || (context == dir->context()))
+            return true;
+    }
+    return false;
+}
+
 KIcon KIconTheme::iconPath(const QString& name, int size, KIcon::MatchType match) const
 {
     KIcon icon;
@@ -453,6 +471,10 @@ QStringList KIconTheme::list()
 
     _theme_list = new QStringList();
     QStringList icnlibs = KGlobal::dirs()->resourceDirs("icon");
+    icnlibs += (KGlobal::dirs()->resourceDirs("xdgdata-icon"));
+    icnlibs += "/usr/share/pixmaps";
+    // These are not in the icon spec, but e.g. GNOME puts some icons there anyway.
+    icnlibs += KGlobal::dirs()->resourceDirs("xdgdata-pixmap");
     QStringList::ConstIterator it;
     for (it=icnlibs.begin(); it!=icnlibs.end(); ++it)
     {
@@ -517,6 +539,20 @@ KIconThemeDir::KIconThemeDir(const QString& dir, const KConfigBase *config)
         mContext = KIcon::Application;
     else if (tmp == "Actions")
         mContext = KIcon::Action;
+    else if (tmp == "Animations")
+        mContext = KIcon::Animation;
+    else if (tmp == "Categories")
+        mContext = KIcon::Category;
+    else if (tmp == "Emblems")
+        mContext = KIcon::Emblem;
+    else if (tmp == "Emotes")
+        mContext = KIcon::Emote;
+    else if (tmp == "International")
+        mContext = KIcon::International;
+    else if (tmp == "Places")
+        mContext = KIcon::Place;
+    else if (tmp == "Status")
+        mContext = KIcon::StatusIcon;
     else {
         kdDebug(264) << "Invalid Context= line for icon theme: " << mDir << "\n";
         return;
