@@ -14,13 +14,16 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  */
 #ifndef KSOCK_H
 #define KSOCK_H
 
-#include "kdemacros.h"
+#include "kdelibs_export.h"
+
+#ifdef Q_OS_UNIX
+
 #include <qobject.h>
 #include <sys/types.h>
 // we define STRICT_ANSI to get rid of some warnings in glibc
@@ -79,10 +82,9 @@ class KServerSocketPrivate;
  * was not successful.
  *
  * @author Torben Weis <weis@uni-frankfurt.de>
- * @version $Id: ksock.h,v 1.63 2003/10/06 07:45:39 bhards Exp $
  * @short A TCP/IP client socket.
  */
-class KDE_DEPRECATED KSocket : public QObject
+class KDECORE_EXPORT KSocket : public QObject
 {
     Q_OBJECT
 public:
@@ -90,20 +92,20 @@ public:
      * Constructs a KSocket with the provided file descriptor.
      * @param _sock	The file descriptor to use.
      */
-    KSocket( int _sock );
+    KSocket( int _sock ) KDE_DEPRECATED;
     /**
      * Creates a socket and connects to a host.
      * @param _host	The remote host to which to connect.
      * @param _port	The port on the remote host.
      * @param timeOut	The number of seconds waiting for connect (default 30).
      */
-    KSocket( const char *_host, unsigned short int _port, int timeOut = 30);
+    KSocket( const char *_host, unsigned short int _port, int timeOut = 30) KDE_DEPRECATED;
 
     /**
      * Connects to a UNIX domain socket.
      * @param _path    The filename of the socket.
      */
-    KSocket( const char * _path );
+    KSocket( const char * _path ) KDE_DEPRECATED;
 
     /**
      * Destructor. Closes the socket if it is still open.
@@ -230,8 +232,10 @@ private:
  * @short Monitors a port for incoming TCP/IP connections.
  *
  * @deprecated
- * This class is deprecated and will be removed in the future. For new
- * programs, please use KExtendedSocket class.
+ * This class is deprecated and will be removed in the future.
+ * Please use the classes in KNetwork for new programs. 
+ * In special, this class is replaced by KNetwork::KStreamSocket
+ * and KNetwork::KServerSocket. 
  *
  * You can use a KServerSocket to listen on a port for incoming
  * connections. When a connection arrived in the port, a KSocket
@@ -242,9 +246,8 @@ private:
  * If socket() is -1 or less the socket was not created properly.
  *
  * @author Torben Weis <weis@stud.uni-frankfurt.de>
- * @version $Id: ksock.h,v 1.63 2003/10/06 07:45:39 bhards Exp $
 */
-class KServerSocket : public QObject
+class KDECORE_EXPORT KServerSocket : public QObject
 {
     Q_OBJECT
 public:
@@ -338,5 +341,6 @@ private:
     KServerSocketPrivate *d;
 };
 
+#endif //Q_OS_UNIX
 
 #endif
