@@ -158,7 +158,9 @@ void Kded::initModules()
      m_dontLoad.clear();
      KConfig *config = kapp->config();
      bool kde_running = !( getenv( "KDE_FULL_SESSION" ) == NULL || getenv( "KDE_FULL_SESSION" )[ 0 ] == '\0' );
-
+    // not the same user like the one running the session (most likely we're run via sudo or something)
+    if( getenv( "KDE_SESSION_UID" ) != NULL && uid_t( atoi( getenv( "KDE_SESSION_UID" ))) != getuid())
+        kde_running = false;
      // Preload kded modules.
      KService::List kdedModules = KServiceType::offers("KDEDModule");
      for(KService::List::ConstIterator it = kdedModules.begin(); it != kdedModules.end(); ++it)
@@ -857,7 +859,7 @@ public:
 extern "C" KDE_EXPORT int kdemain(int argc, char *argv[])
 {
      KAboutData aboutData( "kded", I18N_NOOP("KDE Daemon"),
-        "$Id: kded.cpp 578401 2006-08-29 09:02:43Z kling $",
+        "$Id: kded.cpp 634204 2007-02-16 16:12:23Z lunakl $",
         I18N_NOOP("KDE Daemon - triggers Sycoca database updates when needed"));
 
      KApplication::installSigpipeHandler();
