@@ -19,14 +19,16 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include "kstyle.h"
+
 #include <qapplication.h>
 #include <qbitmap.h>
 #include <qcleanuphandler.h>
@@ -48,15 +50,13 @@
 #include <kpixmap.h>
 #include <kpixmapeffect.h>
 #include <kimageeffect.h>
-#include "kstyle.h"
 
-//#if defined Q_WS_X11
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-#include <X11/Xlib.h>
-#  ifdef HAVE_XRENDER
+#ifdef Q_WS_X11
+# include <X11/Xlib.h>
+# ifdef HAVE_XRENDER
 #  include <X11/extensions/Xrender.h> // schroder
-extern bool qt_use_xrender;
-#  endif
+   extern bool qt_use_xrender;
+# endif
 #else
 #undef HAVE_XRENDER
 #endif
@@ -238,7 +238,7 @@ KStyle::~KStyle()
 QString KStyle::defaultStyle()
 {
 	if (QPixmap::defaultDepth() > 8)
-	   return QString("keramik");
+	   return QString("plastik");
 	else
 	   return QString("light, 3rd revision");
 }
@@ -983,13 +983,12 @@ int KStyle::pixelMetric(PixelMetric m, const QWidget* widget) const
 		case PM_MaximumDragDistance:
 			return -1;
 
-#if QT_VERSION >= 0x030300
 		case PM_MenuBarItemSpacing:
 			return 5;
 
 		case PM_ToolBarItemSpacing:
 			return 0;
-#endif
+
 		case PM_PopupMenuScrollerHeight:
 			return pixelMetric( PM_ScrollBarExtent, 0);
 
@@ -1777,6 +1776,18 @@ int KStyle::styleHint( StyleHint sh, const QWidget* w,
 		case SH_ComboBox_ListMouseTracking:
 		case SH_ScrollBar_MiddleClickAbsolutePosition:
 			return 1;
+		case SH_LineEdit_PasswordCharacter:
+		{
+			if (w) {
+				const QFontMetrics &fm = w->fontMetrics();
+				if (fm.inFont(QChar(0x25CF))) {
+					return 0x25CF;
+				} else if (fm.inFont(QChar(0x2022))) {
+					return 0x2022;
+				}
+			}
+			return '*';
+		}
 
 		default:
 			return QCommonStyle::styleHint(sh, w, opt, shr);
@@ -1936,7 +1947,7 @@ void TransparencyHandler::bottomShadow(QImage& dst)
 // Create a shadow of thickness 4.
 void TransparencyHandler::createShadowWindows(const QPopupMenu* p)
 {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#ifdef Q_WS_X11
 	int x2 = p->x()+p->width();
 	int y2 = p->y()+p->height();
 	QRect shadow1(x2, p->y() + 4, 4, p->height());
@@ -1983,7 +1994,7 @@ void TransparencyHandler::createShadowWindows(const QPopupMenu* p)
 
 void TransparencyHandler::removeShadowWindows(const QPopupMenu* p)
 {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#ifdef Q_WS_X11
 	ShadowMap::iterator it = shadowMap().find(p);
 	if (it != shadowMap().end())
 	{
@@ -2002,7 +2013,7 @@ void TransparencyHandler::removeShadowWindows(const QPopupMenu* p)
 
 bool TransparencyHandler::eventFilter( QObject* object, QEvent* event )
 {
-#ifndef Q_WS_MAC
+#if !defined Q_WS_MAC && !defined Q_WS_WIN
 	// Transparency idea was borrowed from KDE2's "MegaGradient" Style,
 	// Copyright (C) 2000 Daniel M. Duley <mosfet@kde.org>
 
