@@ -1,8 +1,6 @@
 /*
  *  This file is part of the KDE libraries
- *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
- *
- *  $Id: kmcupsuimanager.h,v 1.3 2001/03/30 21:48:47 waba Exp $
+ *  Copyright (c) 2001 Michael Goffioul <kdeprint@swing.be>
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -15,8 +13,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef KMCUPSUIMANAGER_H
@@ -27,13 +25,16 @@
 class KMCupsUiManager : public KMUiManager
 {
 public:
-	KMCupsUiManager(QObject *parent = 0, const char *name = 0);
+	KMCupsUiManager(QObject *parent, const char *name, const QStringList & /*args*/);
 	~KMCupsUiManager();
 
 	void setupPropertyPages(KMPropertyPage*);
 	void setupWizard(KMWizard*);
 	void setupPrinterPropertyDialog(KPrinterPropertyDialog*);
 	void setupConfigDialog(KMConfigDialog*);
+	int pluginPageCap();
+	void setupPrintDialogPages(QPtrList<KPrintDialogPage>*);
+	void setupJobViewer(QListView*);
 };
 
 #endif
