@@ -13,8 +13,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #ifndef SIDEPIXMAP_H
@@ -23,7 +23,9 @@
 #include <qframe.h>
 #include <qpixmap.h>
 
-class SidePixmap : public QFrame
+#include <kdelibs_export.h>
+
+class KDEPRINT_EXPORT SidePixmap : public QFrame
 {
 public:
 	SidePixmap(QWidget *parent = 0, const char *name = 0);
