@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU Lesser General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _KCOMBOBOX_H
@@ -35,6 +35,8 @@ class KCompletionBox;
 class KURL;
 
 /**
+ * @short An enhanced combo box.
+ *
  * A combined button, line-edit and a popup list widget.
  *
  * \b Detail \n
@@ -60,8 +62,12 @@ class KURL;
  * KComboBox will by default handle text rotation and completion events
  * internally whenever a completion object is created through either one of the
  * methods mentioned above.  If you do not need this functionality, simply use
- * KCompletionBase::setHandleSignals(bool) or alternatively set the boolean
- * parameter in the @p setCompletionObject call to false.
+ * @p setHandleSignals(bool) or alternatively set the boolean parameter in the
+ * @p setCompletionObject call to false.
+ *
+ * Beware: The completion object can be deleted on you, especially if a call
+ * such as setEditable(false) is made.  Store the pointer at your own risk,
+ * and consider using QGuardedPtr<KCompletion>.
  *
  * The default key-bindings for completion and rotation is determined from the
  * global settings in KStdAccel. These values, however, can be overridden
@@ -71,7 +77,7 @@ class KURL;
  * key-bindings by usning setKeyBinding() with the default second argument.
  *
  * A non-editable combobox only has one completion mode, @p CompletionAuto.
- * Unlike an editable combobox the CompletionAuto mode, works by matching 
+ * Unlike an editable combobox the CompletionAuto mode, works by matching
  * any typed key with the first letter of entries in the combobox. Please note
  * that if you call setEditable( false ) to change an editable combobox to a
  * non-editable one, the text completion object associated with the combobox will
@@ -83,16 +89,16 @@ class KURL;
  * KComboBox* combo = new KCompletionBox(true, this, "mywidget");
  * KCompletion* comp = combo->completionObject();
  * combo->setEditable( false );
- * comp->clear(); // CRASH: completion object does not exist anymore. 
+ * comp->clear(); // CRASH: completion object does not exist anymore.
  * \endcode
  *
  *
- * A read-only KComboBox will have the same background color as a 
+ * A read-only KComboBox will have the same background color as a
  * disabled KComboBox, but its foreground color will be the one used for
  * the read-write mode. This differs from QComboBox's implementation
- * and is done to give visual distinction between the three different modes: 
+ * and is done to give visual distinction between the three different modes:
  * disabled, read-only, and read-write.
- * 
+ *
  * \b Usage \n
  *
  * To enable the basic completion feature:
@@ -133,15 +139,15 @@ class KURL;
  * combo->setContextMenuEnabled( false );
  * \endcode
  *
- * @short An enhanced combo box.
  * @author Dawit Alemayehu <adawit@kde.org>
  */
-class KComboBox : public QComboBox, public KCompletionBase
+class KDEUI_EXPORT KComboBox : public QComboBox, public KCompletionBase
 {
   Q_OBJECT
   Q_PROPERTY( bool autoCompletion READ autoCompletion WRITE setAutoCompletion )
   Q_PROPERTY( bool contextMenuEnabled READ isContextMenuEnabled WRITE setContextMenuEnabled )
   Q_PROPERTY( bool urlDropsEnabled READ isURLDropsEnabled WRITE setURLDropsEnabled )
+  Q_PROPERTY( bool trapReturnKey READ trapReturnKey WRITE setTrapReturnKey )
 
 public:
 
@@ -290,7 +296,7 @@ public:
 
     /**
      * By default, KComboBox recognizes Key_Return and Key_Enter
-     * and emits the returnPressed() signals, but it also lets the 
+     * and emits the returnPressed() signals, but it also lets the
      * event pass, for example causing a dialog's default-button to
      * be called.
      *
@@ -372,10 +378,10 @@ signals:
    /**
     * Emitted when the text rotation key-bindings are pressed.
     *
-    * The argument indicates which key-binding was pressed. In this case this
-    * can be either one of four values: @p PrevCompletionMatch,
+    * The argument indicates which key-binding was pressed. In this
+    * case this can be either one of four values: @p PrevCompletionMatch,
     * @p NextCompletionMatch, @p RotateUp or @p RotateDown. See
-    * KCompletionBase::setKeyBinding() for details.
+    * @p setKeyBinding() for details.
     *
     * Note that this signal is @em NOT emitted if the completion
     * mode is set to CompletionNone.
@@ -423,8 +429,7 @@ public slots:
     /**
      * Sets the completed text in the line-edit appropriately.
      *
-     * This function is an implementation for
-     * KCompletionBase::setCompletedText.
+     * This function is a re-implementation of @p setCompletedText.
      */
     virtual void setCompletedText( const QString& );
 
@@ -440,6 +445,7 @@ public slots:
      * no item is selected.
      */
     void setCurrentItem( const QString& item, bool insert = false, int index = -1 );
+
     /**
      * Simply calls QComboBox' implementation. Only here to not become
      * shadowed.
@@ -501,13 +507,15 @@ protected:
 
 private:
     class KComboBoxPrivate;
-    KComboBoxPrivate *d;
+    KComboBoxPrivate* const d;
 };
 
 
 class KPixmapProvider;
 
 /**
+ * @short A combobox for offering a history and completion
+ *
  * A combobox which implements a history like a unix shell. You can navigate
  * through all the items by using the Up or Down arrows (configurable of
  * course). Additionally, weighted completion is available. So you should
@@ -521,9 +529,8 @@ class KPixmapProvider;
  * "ignoreboth". Otherwise, duplicates are enabled by default.
  *
  * @author Carsten Pfeiffer <pfeiffer@kde.org>
- * @short A combobox for offering a history and completion
  */
-class KHistoryCombo : public KComboBox
+class KDEUI_EXPORT KHistoryCombo : public KComboBox
 {
     Q_OBJECT
     Q_PROPERTY( QStringList historyItems READ historyItems WRITE setHistoryItems )
@@ -719,7 +726,7 @@ protected:
     /**
      * @returns if we can modify the completion object or not.
      */
-    bool useCompletion() const { return compObj() != 0L; }
+    bool useCompletion() const { return compObj(); }
 
 private slots:
     /**
@@ -764,7 +771,7 @@ protected:
     virtual void virtual_hook( int id, void* data );
 private:
     class KHistoryComboPrivate;
-    KHistoryComboPrivate *d;
+    KHistoryComboPrivate* const d;
 };
 
 
