@@ -18,14 +18,15 @@
 
      You should have received a copy of the GNU Library General Public License
      along with this library; see the file COPYING.LIB.  If not, write to
-     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
  */
 #include "config.h"
 
 #include "kmainwindow.h"
 #include "kmainwindowiface.h"
 #include "ktoolbarhandler.h"
+#include "kwhatsthismanager_p.h"
 #include <qsessionmanager.h>
 #include <qobjectlist.h>
 #include <qstyle.h>
@@ -48,7 +49,7 @@
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kstaticdeleter.h>
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
+#if defined Q_WS_X11
 #include <netwm.h>
 #endif
 
@@ -177,6 +178,7 @@ KMainWindow::KMainWindow( int cflags, QWidget* parent, const char *name, WFlags
 
 void KMainWindow::initKMainWindow(const char *name, int cflags)
 {
+    KWhatsThisManager::init ();
     setDockMenuEnabled( false );
     mHelpMenu = 0;
     kapp->setTopWidget( this );
@@ -197,7 +199,7 @@ void KMainWindow::initKMainWindow(const char *name, int cflags)
         s = objname + '1'; // start adding number immediately
         unusedNumber = 1;
         }
-    else if( name[ strlen( name ) - 1 ] == '#' )
+    else if( name[0] != '\0' && name[ strlen( name ) - 1 ] == '#' )
         { // trailing # - always add a number
         objname = name;
         s = objname + '1'; // start adding number immediately
@@ -279,18 +281,16 @@ void KMainWindow::parseGeometry(bool parsewidth)
     assert ( !kapp->geometryArgument().isNull() );
     assert ( d->care_about_geometry );
 
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifndef Q_WS_QWS
-    // FIXME: (E) Implement something similar for Qt Embedded (or decide we don't need it)
+#if defined Q_WS_X11
     int x, y;
     int w, h;
     int m = XParseGeometry( kapp->geometryArgument().latin1(), &x, &y, (unsigned int*)&w, (unsigned int*)&h);
     if (parsewidth) {
         QSize minSize = minimumSize();
         QSize maxSize = maximumSize();
-        if ( (m & WidthValue) == 0 )
+        if ( !(m & WidthValue) )
             w = width();
-        if ( (m & HeightValue) == 0 )
+        if ( !(m & HeightValue) )
             h = height();
          w = QMIN(w,maxSize.width());
          h = QMIN(h,maxSize.height());
@@ -298,9 +298,9 @@ void KMainWindow::parseGeometry(bool parsewidth)
          h = QMAX(h,minSize.height());
          resize(w, h);
     } else {
-        if ( parsewidth && (m & XValue) == 0 )
+        if ( parsewidth && !(m & XValue) )
             x = geometry().x();
-        if ( parsewidth && (m & YValue) == 0 )
+        if ( parsewidth && !(m & YValue) )
             y = geometry().y();
         if ( (m & XNegative) )
             x = KApplication::desktop()->width()  + x - w;
@@ -323,13 +323,13 @@ KMainWindow::~KMainWindow()
 
 KPopupMenu* KMainWindow::helpMenu( const QString &aboutAppText, bool showWhatsThis )
 {
-    if( mHelpMenu == 0 ) {
+    if( !mHelpMenu ) {
         if ( aboutAppText.isEmpty() )
             mHelpMenu = new KHelpMenu( this, instance()->aboutData(), showWhatsThis);
         else
             mHelpMenu = new KHelpMenu( this, aboutAppText, showWhatsThis );
 
-        if ( mHelpMenu == 0 )
+        if ( !mHelpMenu )
             return 0;
         connect( mHelpMenu, SIGNAL( showAboutApplication() ),
                  this, SLOT( showAboutApplication() ) );
@@ -340,7 +340,7 @@ KPopupMenu* KMainWindow::helpMenu( const QString &aboutAppText, bool showWhatsTh
 
 KPopupMenu* KMainWindow::customHelpMenu( bool showWhatsThis )
 {
-    if( mHelpMenu == 0 ) {
+    if( !mHelpMenu ) {
         mHelpMenu = new KHelpMenu( this, QString::null, showWhatsThis );
         connect( mHelpMenu, SIGNAL( showAboutApplication() ),
                  this, SLOT( showAboutApplication() ) );
@@ -443,6 +443,10 @@ void KMainWindow::saveNewToolbarConfig()
 }
 
 void KMainWindow::setupGUI( int options, const QString & xmlfile ) {
+    setupGUI(QSize(), options, xmlfile);
+}
+
+void KMainWindow::setupGUI( QSize defaultSize, int options, const QString & xmlfile ) {
     if( options & Keys ){
         KStdAction::keyBindings(guiFactory(),
                     SLOT(configureShortcuts()), actionCollection());
@@ -459,7 +463,7 @@ void KMainWindow::setupGUI( int options, const QString & xmlfile ) {
     }
 
     if( options & Create ){
-        createGUI(xmlfile);
+        createGUI(xmlfile,false);
     }
 
     if( options & Save ){
@@ -467,8 +471,18 @@ void KMainWindow::setupGUI( int options, const QString & xmlfile ) {
         // so the default window size will be incorrect unless the application
         // hard coded the size which they should try not to do (i.e. use
         // size hints).
-        if(!isShown())
+        if(initialGeometrySet())
+        {
+          // Do nothing...
+        }
+        else if(defaultSize.isValid())
+        {
+          resize(defaultSize);
+        }
+        else if(!isShown())
+        {
           adjustSize();
+        }
         setAutoSaveSettings();
     }
 
@@ -495,7 +509,7 @@ void KMainWindow::createGUI( const QString &xmlfile, bool _conserveMemory )
     // don't build a help menu unless the user ask for it
     if (d->showHelpMenu) {
         // we always want a help menu
-        if (helpMenu2 == 0)
+        if (!helpMenu2)
             helpMenu2 = new KHelpMenu(this, instance()->aboutData(), true,
                                       actionCollection());
     }
@@ -577,8 +591,7 @@ void KMainWindow::setCaption( const QString &caption, bool modified )
 void KMainWindow::setPlainCaption( const QString &caption )
 {
     QMainWindow::setCaption( caption );
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
-//#ifndef Q_WS_QWS
+#if defined Q_WS_X11
     NETWinInfo info( qt_xdisplay(), winId(), qt_xrootwin(), 0 );
     info.setName( caption.utf8().data() );
 #endif
@@ -586,9 +599,9 @@ void KMainWindow::setPlainCaption( const QString &caption )
 
 void KMainWindow::appHelpActivated( void )
 {
-    if( mHelpMenu == 0 ) {
+    if( !mHelpMenu ) {
         mHelpMenu = new KHelpMenu( this );
-        if ( mHelpMenu == 0 )
+        if ( !mHelpMenu )
             return;
     }
     mHelpMenu->appHelpActivated();
@@ -777,7 +790,7 @@ void KMainWindow::setStandardToolBarMenuEnabled( bool enable )
 
 bool KMainWindow::isStandardToolBarMenuEnabled() const
 {
-    return ( d->toolBarHandler != 0 );
+    return ( d->toolBarHandler );
 }
 
 void KMainWindow::createStandardStatusBarAction(){
@@ -821,8 +834,8 @@ void KMainWindow::applyMainWindowSettings(KConfig *config, const QString &config
 void KMainWindow::applyMainWindowSettings(KConfig *config, const QString &configGroup,bool force)
 {
     kdDebug(200) << "KMainWindow::applyMainWindowSettings" << endl;
-    if (!configGroup.isEmpty())
-       config->setGroup(configGroup);
+
+    KConfigGroupSaver saver( config, configGroup.isEmpty() ? config->group() : configGroup );
 
     restoreWindowSize(config);
 
@@ -879,28 +892,31 @@ void KMainWindow::finalizeGUI( bool force )
     // the toolbariterator should give them in the proper order.
     // Both the XMLGUI and applySettings call this, hence "force" for the latter.
     QPtrListIterator<KToolBar> it( toolBarIterator() );
-    for ( ; it.current() ; ++ it )
-            it.current()->positionYourself( force );
+    for ( ; it.current() ; ++it ) {
+        it.current()->positionYourself( force );
+    }
 
     d->settingsDirty = false;
 }
 
 void KMainWindow::saveWindowSize( KConfig * config ) const
 {
-#if defined Q_WS_X11 && ! defined K_WS_QTONLY
   int scnum = QApplication::desktop()->screenNumber(parentWidget());
   QRect desk = QApplication::desktop()->screenGeometry(scnum);
+  int w, h;
+#if defined Q_WS_X11
   // save maximalization as desktop size + 1 in that direction
   KWin::WindowInfo info = KWin::windowInfo( winId(), NET::WMState );
-  int w = info.state() & NET::MaxHoriz ? desk.width() + 1 : width();
-  int h = info.state() & NET::MaxVert ? desk.height() + 1 : height();
-  QRect size( desk.width(), w, desk.height(), h );
+  w = info.state() & NET::MaxHoriz ? desk.width() + 1 : width();
+  h = info.state() & NET::MaxVert ? desk.height() + 1 : height();
 #else
-  int w = 500;
-  int h = 500;
-  QRect desk( 100, 100, 200, 200 ); // fixme
-  QRect size( 100, 100, 200, 200 ); // fixme
+  if (isMaximized()) {
+    w = desk.width() + 1;
+    h = desk.height() + 1;
+  }
+  //TODO: add "Maximized" property instead "+1" hack
 #endif
+  QRect size( desk.width(), w, desk.height(), h );
   bool defaultSize = (size == d->defaultWindowSize);
   QString widthString = QString::fromLatin1("Width %1").arg(desk.width());
   QString heightString = QString::fromLatin1("Height %1").arg(desk.height());
@@ -938,6 +954,7 @@ void KMainWindow::restoreWindowSize( KConfig * config )
             }
         }
         if ( !size.isEmpty() ) {
+#ifdef Q_WS_X11
             int state = ( size.width() > desk.width() ? NET::MaxHoriz : 0 )
                         | ( size.height() > desk.height() ? NET::MaxVert : 0 );
             if(( state & NET::Max ) == NET::Max )
@@ -950,6 +967,12 @@ void KMainWindow::restoreWindowSize( KConfig * config )
                 resize( size );
             // QWidget::showMaximized() is both insufficient and broken
             KWin::setState( winId(), state );
+#else
+            if (size.width() > desk.width() || size.height() > desk.height())
+              setWindowState( WindowMaximized );
+            else
+              resize( size );
+#endif
         }
     }
 }
@@ -997,6 +1020,8 @@ void KMainWindow::setAutoSaveSettings( const QString & groupName, bool saveWindo
     d->autoSaveGroup = groupName;
     d->autoSaveWindowSize = saveWindowSize;
     // Get notified when the user moves a toolbar around
+    disconnect( this, SIGNAL( dockWindowPositionChanged( QDockWindow * ) ),
+                this, SLOT( setSettingsDirty() ) );
     connect( this, SIGNAL( dockWindowPositionChanged( QDockWindow * ) ),
              this, SLOT( setSettingsDirty() ) );
 
@@ -1120,7 +1145,7 @@ KToolBar *KMainWindow::toolBar( const char * name )
     KToolBar *tb = (KToolBar*)child( name, "KToolBar" );
     if ( tb )
         return tb;
-    bool honor_mode = (name == "mainToolBar");
+    bool honor_mode = (!strcmp(name, "mainToolBar"));
 
     if ( builderClient() )
         return new KToolBar(this, name, honor_mode); // XMLGUI constructor
@@ -1200,11 +1225,15 @@ QSize KMainWindow::sizeForCentralWidgetSize(QSize size)
 void KMainWindow::setIcon( const QPixmap& p )
 {
     QMainWindow::setIcon( p );
+#ifdef Q_WS_X11 
     // Qt3 doesn't support _NET_WM_ICON, but KApplication::setTopWidget(), which
     // is used by KMainWindow, sets it
     KWin::setIcons( winId(), p, QPixmap());
+#endif
 }
 
+QPtrList<KMainWindow>* KMainWindow::getMemberList() { return memberList; }
+
 // why do we support old gcc versions? using KXMLGUIBuilder::finalizeGUI;
 // DF: because they compile KDE much faster :)
 void KMainWindow::finalizeGUI( KXMLGUIClient *client )
