@@ -17,11 +17,13 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include <config.h>
 
 #include <qcheckbox.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qlayout.h>
+#include <qtimer.h>
 
 #include <kapplication.h>
 #include <kconfig.h>
@@ -237,7 +239,7 @@ KSpellConfig::sChangeClient( int i )
       dictcombo->clear();
       dictcombo->insertItem( i18n("Turkish") );
       sChangeEncoding( KS_E_UTF8 );
-    } 
+    }
     else
       getAvailDictsAspell();
   }
@@ -438,9 +440,9 @@ void KSpellConfig::getAvailDictsIspell () {
   dictcombo->insertItem( i18n("ISpell Default") );
 
   // dictionary path
-  QFileInfo dir ("/usr/lib/ispell");
+  QFileInfo dir ("/usr/lib" KDELIBSUFF "/ispell");
   if (!dir.exists() || !dir.isDir())
-    dir.setFile ("/usr/local/lib/ispell");
+    dir.setFile ("/usr/local/lib" KDELIBSUFF "/ispell");
   if (!dir.exists() || !dir.isDir())
     dir.setFile ("/usr/local/share/ispell");
   if (!dir.exists() || !dir.isDir())
@@ -503,13 +505,13 @@ void KSpellConfig::getAvailDictsAspell () {
   langfnames.append(""); // Default
   dictcombo->insertItem (i18n("ASpell Default"));
 
-  // dictionary path
-  // FIXME: use "aspell dump config" to find out the dict-dir
-  QFileInfo dir ("/usr/lib/aspell");
+  // Aspell now have /usr/lib/aspell as
+  // ASPELL_DATADIR default.
+  QFileInfo dir ( ASPELL_DATADIR );
   if (!dir.exists() || !dir.isDir())
-    dir.setFile ("/usr/lib/aspell-0.60");
+    dir.setFile ("/usr/lib" KDELIBSUFF "/aspell-0.60");
   if (!dir.exists() || !dir.isDir())
-    dir.setFile ("/usr/local/lib/aspell");
+    dir.setFile ("/usr/local/lib" KDELIBSUFF "/aspell");
   if (!dir.exists() || !dir.isDir())
     dir.setFile ("/usr/share/aspell");
   if (!dir.exists() || !dir.isDir())
@@ -661,11 +663,11 @@ KSpellConfig::fillDicts( QComboBox* box, QStringList* dictionaries )
 
       // dictionary path
       // FIXME: use "aspell dump config" to find out the dict-dir
-      QFileInfo dir ("/usr/lib/aspell");
+      QFileInfo dir ("/usr/lib" KDELIBSUFF "/aspell");
       if (!dir.exists() || !dir.isDir())
-        dir.setFile ("/usr/lib/aspell-0.60");
+        dir.setFile ("/usr/lib" KDELIBSUFF "/aspell-0.60");
       if (!dir.exists() || !dir.isDir())
-        dir.setFile ("/usr/local/lib/aspell");
+        dir.setFile ("/usr/local/lib" KDELIBSUFF "/aspell");
       if (!dir.exists() || !dir.isDir())
         dir.setFile ("/usr/share/aspell");
       if (!dir.exists() || !dir.isDir())
@@ -907,7 +909,7 @@ KSpellConfig::sSetDictionary (int i)
 {
   setDictionary (langfnames[i]);
   setDictFromList (true);
-  emit configChanged();
+  QTimer::singleShot( 0, this, SIGNAL( configChanged() ) );
 }
 
 void
