@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * This file includes excerpts from the Document Object Model (DOM)
  * Level 1 Specification (Recommendation)
@@ -25,12 +25,16 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
+ * This file includes excerpts from the Document Object Model (DOM)
+ * Level 3 Core Specification (Recommendation)
+ * http://www.w3.org/TR/DOM-Level-3-Core/
+ * Copyright ©2004 W3C® (MIT, ERCIM, Keio), All Rights Reserved.
  */
 #ifndef _DOM_Node_h_
 #define _DOM_Node_h_
 
 #include <qstring.h>
-#include <kdemacros.h>
+#include <kdelibs_export.h>
 
 class QRect;
 
@@ -59,7 +63,7 @@ class Event;
  * imply that the DOM specifies an order to these Nodes.
  *
  */
-class NamedNodeMap
+class KHTML_EXPORT NamedNodeMap
 {
 public:
     NamedNodeMap();
@@ -267,7 +271,7 @@ class NodeImpl;
  * mechanisms to get and set the relevant information.
  *
  */
-class Node
+class KHTML_EXPORT Node
 {
     friend class NamedNodeMap;
     friend class NodeList;
@@ -750,6 +754,34 @@ public:
      */
     bool hasAttributes (  );
 
+    /**
+     * Introduced in DOM Level 3
+     *
+     * This attribute returns the text content of this node and its descendants. 
+     * On getting, no serialization is performed, the returned string does not contain any markup.
+     *
+     * @since 3.5.7
+     */
+    DOMString textContent( ) const;
+
+    /**
+     * Introduced in DOM Level 3
+     *
+     * @see textContent
+     *
+     * On setting, any possible children this node may have are removed and, if the new 
+     * string is not empty or null, replaced by a single Text node containing the string this attribute is set to. 
+     * No parsing is performed, the input string is taken as pure textual content.
+     *
+     * @exception DOMException
+     * NO_MODIFICATION_ALLOWED_ERR: Raised if this node is readonly.
+     * Note: KHTML will also raise this if setContent is called on things
+     * that do not have child nodes.
+     *
+     * @since 3.5.7
+     */
+    void setTextContent(const DOMString &content) const;
+
     /**
      * Introduced in DOM Level 2
      * This method is from the EventTarget interface
@@ -836,6 +868,8 @@ public:
      */
     bool dispatchEvent(const Event &evt);
 
+
+
     /**
      * @internal
      * not part of the DOM.
@@ -866,7 +900,7 @@ public:
      * @internal returns the index of a node
      */
     unsigned long index() const;
-    QString toHTML();
+    QString toHTML() KDE_DEPRECATED;
     void applyChanges();
     /**
      * @deprecated without substitution since 3.2
@@ -894,7 +928,7 @@ class NodeListImpl;
  * integral index, starting from 0.
  *
  */
-class NodeList
+class KHTML_EXPORT NodeList
 {
     friend class Element;
     friend class Node;
