@@ -3,7 +3,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Waldo Bastian <bastian@kde.org>
  *
- * $Id: autostart.cpp 507484 2006-02-09 11:20:19Z jriddell $
+ * $Id: autostart.cpp 534738 2006-04-27 18:04:45Z lunakl $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -42,8 +42,8 @@ public:
    AutoStartList() { }
 };
 
-AutoStart::AutoStart()
-  : m_phase(0), m_phasedone(false)
+AutoStart::AutoStart( bool new_startup )
+  : m_newStartup( new_startup ), m_phase( new_startup ? -1 : 0), m_phasedone(false)
 {
   m_startList = new AutoStartList;
   m_startList->setAutoDelete(true);
@@ -133,9 +133,18 @@ AutoStart::loadAutoStartList()
        item->name = extractName(*it);
        item->service = *it;
        item->startAfter = config.readEntry("X-KDE-autostart-after");
-       item->phase = config.readNumEntry("X-KDE-autostart-phase", 1);
-       if (item->phase < 1)
-          item->phase = 1;
+       if( m_newStartup )
+       {
+          item->phase = config.readNumEntry("X-KDE-autostart-phase", 2);
+          if (item->phase < 0)
+             item->phase = 0;
+       }
+       else
+       {
+          item->phase = config.readNumEntry("X-KDE-autostart-phase", 1);
+          if (item->phase < 1)
+             item->phase = 1;
+       }
        m_startList->append(item);
    }
 } 
