@@ -14,14 +14,15 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include <qfile.h>
 
 #include <kfileitem.h>
 #include <kdebug.h>
+#include <kde_file.h>
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -160,7 +161,7 @@ void KFileTreeBranch::addItems( const KFileItemList& list )
     while ( (currItem = it.current()) != 0 )
     {
         parentItem = parentKFTVItem( currItem );
-        
+
 
         /* Only create a new KFileTreeViewItem if it does not yet exist */
         KFileTreeViewItem *newKFTVI =
@@ -199,8 +200,8 @@ void KFileTreeBranch::addItems( const KFileItemList& list )
              *  count only contains directory links. Thus, this method only seem
              * to work in dir-only mode */
             kdDebug(250) << "Doing stat on " << filename << endl;
-            struct stat statBuf;
-            if( stat( QFile::encodeName( filename ), &statBuf ) == 0 )
+            KDE_struct_stat statBuf;
+            if( KDE_stat( QFile::encodeName( filename ), &statBuf ) == 0 )
             {
                 int hardLinks = statBuf.st_nlink;  /* Count of dirs */
                 kdDebug(250) << "stat succeeded, hardlinks: " << hardLinks << endl;
@@ -299,7 +300,7 @@ void KFileTreeBranch::slotDeleteItem( KFileItem *it )
         }
 
         kdDebug(250) << "Found corresponding KFileTreeViewItem" << endl;
-        if( m_lastFoundURL.equals( it->url(), true ))
+        if( m_lastFoundURL.equals(it->url(), true ))
         {
           m_lastFoundURL = KURL();
           m_lastFoundItem = 0L;
