@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 #include <config.h>
 
@@ -87,11 +87,11 @@ protected:
 
 
 //----------------------------------------------------------------------------
-#ifdef Q_WS_QWS
+#if defined(Q_WS_QWS) || defined(Q_WS_MACX)
 typedef WId Window;
 #endif
 
-int main(int argc, char *argv[])
+KDE_EXPORT int main(int argc, char *argv[])
 {
     KLocale::setMainCatalogue("libkscreensaver");
     KCmdLineArgs::init(argc, argv, kss_applicationName, kss_description, kss_version);
